# generated by datamodel-codegen:
#   filename:  media_buy/sync_creatives_async_response_submitted.json
#   timestamp: 2026-01-08T19:25:24+00:00

from __future__ import annotations

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict

from ..core import context as context_1
from ..core import ext as ext_1


class SyncCreativesSubmitted(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    context: context_1.ContextObject | None = None
    ext: ext_1.ExtensionObject | None = None
