# generated by datamodel-codegen:
#   filename:  enums/task_type.json
#   timestamp: 2025-11-29T12:00:45+00:00

from __future__ import annotations

from enum import Enum


class TaskType(Enum):
    create_media_buy = 'create_media_buy'
    update_media_buy = 'update_media_buy'
    sync_creatives = 'sync_creatives'
    activate_signal = 'activate_signal'
    get_signals = 'get_signals'
