# generated by datamodel-codegen:
#   filename:  core/brand_manifest_ref.json
#   timestamp: 2025-12-11T15:09:37+00:00

from __future__ import annotations

from typing import Annotated

from pydantic import AnyUrl, Field, RootModel

from . import brand_manifest


class BrandManifestReference(RootModel[brand_manifest.BrandManifest | AnyUrl]):
    root: Annotated[
        brand_manifest.BrandManifest | AnyUrl,
        Field(
            description='Brand manifest provided either as an inline object or a URL string pointing to a hosted manifest',
            examples=[
                {
                    'data': {
                        'colors': {'primary': '#FF6B35'},
                        'name': 'ACME Corporation',
                        'url': 'https://acmecorp.com',
                    },
                    'description': 'Inline brand manifest',
                },
                {
                    'data': 'https://cdn.acmecorp.com/brand-manifest.json',
                    'description': 'URL string reference to hosted manifest',
                },
            ],
            title='Brand Manifest Reference',
        ),
    ]
